@@ -3,7 +3,7 @@ package Locale::TextDomain::OO; ## no critic (TidyCode)
 use strict;
 use warnings;
 
-our $VERSION = '1.019';
+our $VERSION = '1.020';
 
 use Locale::TextDomain::OO::Translator;
 
@@ -36,13 +36,13 @@ __END__
 
 Locale::TextDomain::OO - Perl OO Interface to Uniforum Message Translation
 
-$Id: OO.pm 580 2015-04-12 20:09:18Z steffenw $
+$Id: OO.pm 603 2015-08-09 16:46:25Z steffenw $
 
 $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/module/trunk/lib/Locale/TextDomain/OO.pm $
 
 =head1 VERSION
 
-1.019
+1.020
 
 Starting with version 1.000 the interface has changed.
 
@@ -64,24 +64,24 @@ like L<Locale::Maketext|Locale::Maketext>.
 You decide what you need.
 
 There are some plugins, so it is possible
-to use the maketext and/or getext style.
+to use the Maketext and/or Gettext style.
 
 Locale::TextDomain::OO has a flexible object oriented interface
 based on L<Moo|Moo>.
 
-Creating the Lexicon and translating are two splitted things.
+Creating the Lexicon and translating are two split things.
 So it is possible to create the lexicon during the initialization phase.
-The connection between both is the singleton mechanimsm of the lexicon module.
+The connection between both is the singleton mechanism of the lexicon module.
 
 =head2 Plugin for the web framework?
 
-This module is currently used in a Catalyst based web project.
+This module was first used in a Catalyst based web project.
 
-It is great to call everything on the Catalyst context object.
-It is was great until we used module in web and shell scripts together
+It was great to call everything on the Catalyst context object.
+It was great until we used module in web and shell scripts together
 and called the translation methods there.
 
-What we have done was removing the Catalyst maketext plugin.
+What we have done was removing the Catalyst Maketext plugin.
 We are using a role in the Catalyst application
 and so we can call all the translation methods
 on the Catalyst context object like before.
@@ -93,7 +93,7 @@ In that roles we delegate a bunch of methods
 to Locale::TextDomain::OO.
 We also added our project specific methods there.
 
-Write you own role. There is no need for a common plugin.
+Write you own role. There is no need for a plugin for any framework.
 
 =head2 Who is setting the languages?
 
@@ -115,22 +115,51 @@ Or your application has a language selection menu.
 
 Use module
 L<Locale::TextDomain::OO::Extract|Locale::TextDomain::OO::Extract>.
-This is a base class for all source scanner to create pot files.
+This is a base class for all source scanner to create po/pot files.
 Use this base class and give this module the rules
-or use one of the already exteded classes.
+or use one of the already extended classes.
 L<Locale::TextDomain::OO::Extract::Perl|Locale::TextDomain::OO::Extract::Perl>
 is a extension for Perl code and so on.
 
+=head2 How to build the lexicon - without Gettext tools?
+
+Use module
+L<Locale::TextDomain::OO::Extract::Process|Locale::TextDomain::OO::Extract::Process>.
+This is able to read, strip, extract, merge, write and clean PO and MO files.
+
+There is a module named
+L<Locale::TextDomain::OO::Util::JoinSplitLexiconKeys|Locale::TextDomain::OO::Util::JoinSplitLexiconKeys>.
+That helps you to build the lexicon keys.
+Do not join the keys by yourself, it can break in future versions.
+Use the category, domain, language and project part to describe your lexicon.
+category, domain and language you can use during translation.
+The only reason for project is to separate your different lexicons.
+
+=head2 How to use the lexicon?
+
+The lexicons or all lexicons are stored in memory.
+The idea to build a combined lexicon is overwriting hash values by same key.
+So read and overwrite common stuff with specials.
+In an example case the region file en-gb.mo contains only the differences.
+The common file en.mo contains all messages.
+So it is possible to create full lexicons for any language and region.
+What you have to describe is:
+Where are the files - directories.
+Pick up the common file en.mo as en.
+Pick up the common file en.mo and the special en-gb.mo as en-gb.
+
 =head2 Do not follow the dead end of Locale::Maketext!
 
-What is the problem of?
+But is is allowed to use that writing for backward compatiblity.
+
+What is the problem of Maketext?
 
 =over
 
 =item *
 
 Locale::Maketext allows 2 plural forms (and zero) only.
-This is changable,
+This is changeable,
 but the developer has to control the plural forms.
 He is not an omniscient translator.
 
@@ -159,7 +188,7 @@ A plural form can not be before a number.
     It is 1 book.
     These are 2 books.
 
-Gettext used full qualified sentences.
+Gettext is using full qualified sentences.
 
 =item *
 
@@ -199,7 +228,7 @@ This is the reason for another module to have:
 =item *
 
 Endless (real: up to 6) plural forms
-controlled by the translater and not by the developer.
+controlled by the translator and not by the developer.
 
 =item *
 
@@ -213,22 +242,26 @@ Run the examples of this distribution (folder example).
 
 =head2 Overview
 
- Application calls         Application calls   Application calls
- gettext methods           getext and          maketext methods
- (hint: select this)       maketext methods            |
-         |                               |             |
-         v                               v             v
- .-----------------------------------------------------------------.
- | Locale::TextDomain::OO                                          |
- | with plugin LanguageOfLanguages                                 |
- | with plugins Locale::TextDomain::OO::Plugin::Expand::...        |
- |-----------------------------------------------------------------|
- | Gettext                          |\       /| Maketext           |
- | Gettext::DomainAndCategory       | |     | | Maketext::Loc      |
- | Gettext::Loc (hint: select this) | > and < | Maketext::Localise |
- | Gettext::Loc::DomainAndCategory  | |     | | Maketext::Localize |
- | Gettext::Named                   |/       \|                    |
- `-----------------------------------------------------------------'
+ Application calls           Application calls         Application calls
+ Gettext methods             Gettext and               Maketext methods
+ (Hint: select this)         Maketext methods              |
+         |                   (Hint: Maketext already       |
+         |                   exists in your project)       |
+         |                               |                 |
+         v                               v                 v
+ .---------------------------------------------------------------------.
+ | Locale::TextDomain::OO                                              |
+ | with plugin LanguageOfLanguages                                     |
+ | with plugins Locale::TextDomain::OO::Plugin::Expand::...            |
+ |---------------------------------------------------------------------|
+ | Gettext                          |\       /| Maketext               |
+ | Gettext::DomainAndCategory       | |     | |                        |
+ | (experimental)                   | |     | | Maketext::Loc          |
+ | Gettext::Loc (Hint: select this) | > and < | (Hint: select this)    |
+ | Gettext::Loc::DomainAndCategory  | |     | |                        |
+ | (experimental)                   | |     | | Maketext::Localise     |
+ | Gettext::Named (experimental)    |/       \| Maketext::Localize     |
+ `---------------------------------------------------------------------'
                             ^
                             |
  .--------------------------'-----------------.
@@ -250,19 +283,18 @@ Run the examples of this distribution (folder example).
  `-----------'   `-----------'       `----------'       `----------'   |
                                        ^                   ^           |
                                        |                   |           |
-                        build using gettext tools                      |
-                        or Locale::TextDomain::OO::Extract             |
+                        build using                                    |
+                        Locale::TextDomain::OO::Extract                |
                         and Locale::TextDomain::OO::Extract::Process   |
-                        if both are released                           |
                                                                        |
                                   .------------------------------------'
                                   |
                                   v
- .------------------------------------------------------------------.
- | build JSON lexicon using Locale::TextDomain::OO::Lexicon::ToJSON |
- |------------------------------------------------------------------|
- |      to_json      |      to_javascript      |      to_html       |
- `------------------------------------------------------------------'
+ .---------------------------------------------------------------------.
+ | build JSON lexicon using Locale::TextDomain::OO::Lexicon::StoreJSON |
+ |---------------------------------------------------------------------|
+ |       to_json      |       to_javascript       |      to_html       |
+ `---------------------------------------------------------------------'
                                   |
                                   v
               .---------------------------------------.
@@ -281,7 +313,7 @@ Run the examples of this distribution (folder example).
  | javascript/Locale/TextDomain/OO.js                                               |
  | javascript/Locale/TextDomain/OO/Plugin/Expand/Gettext.js                         |
  | javascript/Locale/TextDomain/OO/Plugin/Expand/Gettext/DomainAndCategory.js       |
- | javascript/Locale/TextDomain/OO/Plugin/Expand/Gettext/Loc.js (hint: select this) |
+ | javascript/Locale/TextDomain/OO/Plugin/Expand/Gettext/Loc.js (Hint: select this) |
  | javascript/Locale/TextDomain/OO/Plugin/Expand/Gettext/Loc/DomainAndCategory.js   |
  |                                                                                  |
  | not implemented:                                                                 |
@@ -296,8 +328,8 @@ Run the examples of this distribution (folder example).
          ^                     ^                  ^
          |                     |                  |
  JavaScript calls      JavaScript calls   JavaScript calls
- gettext methods       getext and         maketext methods
- (hint: select this)   maketext methods   (not implemented)
+ Gettext methods       Gettext and        Maketext methods
+ (Hint: select this)   Maketext methods   (not implemented)
                        (not implemented)
 
 =head1 SYNOPSIS
@@ -312,6 +344,7 @@ Run the examples of this distribution (folder example).
         language => 'de',          # default is i-default
         category => 'LC_MESSAGES', # default is q{}
         domain   => 'MyDomain',    # default is q{}
+        project  => 'MyProject',   # default is undef
         filter   => sub {
             my ($self, $translation_ref) = @_;
             # encode if needed
@@ -327,7 +360,7 @@ Run the examples of this distribution (folder example).
         },
     );
 
-This configuration would be use Lexicon "de:LC_MESSAGES:MyDomain".
+This configuration would be use Lexicon "de:LC_MESSAGES:MyDomain::MyProject".
 That lexicon should be filled with data.
 
 =head2 as singleton
@@ -345,7 +378,7 @@ Instead of method new call method instance to get a singleton.
 This plugin can handle named placeholders like C<{name}>.
 For numeric placeholders add attribute C<:num>.
 That allows easier automatic translation and to localize numbers.
-E.g. write C<{books :num}> to msgid, msgid_plural.
+E.g. write C<{books :numf}> to msgid, msgid_plural.
 
 Grammar rules for string placeholders are able to handle affixes.
 The translation office can add attributes,
@@ -430,7 +463,7 @@ write
     $loc->any_method(...);
 
 In case of webserver child or similar,
-set the language for every reqeuest not as parameter of the first instance call.
+set the language for every request not as parameter of the first instance call.
 
 =head2 method language
 
@@ -537,7 +570,7 @@ not known
 
 =head1 BUGS AND LIMITATIONS
 
-In the gettext manual you can read at
+In the Gettext manual you can read at
 "15.5.18.9 Bugs, Pitfalls, And Things That Do Not Work"
 something that is not working with Perl.
 The examples there are rewritten and explained here.
