@@ -2,7 +2,7 @@ package Locale::TextDomain::OO::Lexicon::StoreJSON; ## no critic (TidyCode)
 
 use strict;
 use warnings;
-use JSON qw(encode_json);
+use JSON ();
 use Moo;
 use MooX::StrictConstructor;
 use namespace::autoclean;
@@ -18,7 +18,11 @@ sub to_json {
     my $self = shift;
 
     return $self->store_content(
-        encode_json( $self->data ),
+        JSON ## no critic (LongChainsOfMethodCalls)
+            ->new
+            ->utf8
+            ->sort_by( sub { $JSON::PP::a cmp $JSON::PP::b } ) ## no critic (PackageVars)
+            ->encode( $self->data ),
     );
 }
 
@@ -50,7 +54,7 @@ __END__
 
 Locale::TextDomain::OO::Lexicon::StoreJSON - Stores the lexicon for other programming languages
 
-$Id: StoreJSON.pm 546 2014-10-31 09:35:19Z steffenw $
+$Id: StoreJSON.pm 604 2015-08-09 16:47:36Z steffenw $
 
 $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/module/trunk/lib/Locale/TextDomain/OO/Lexicon/StoreJSON.pm $
 
